==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebActiveStepChangingArgsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangingArgsDetailDescriptionMetadata } from "./WebActiveStepChangingArgsDetailDescriptionMetadata";
import { WebActiveStepChangingArgsEventArgsDescription } from "./WebActiveStepChangingArgsEventArgsDescription";
/**
 * @hidden
 */
var WebActiveStepChangingArgsEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveStepChangingArgsEventArgsDescriptionMetadata, _super);
    function WebActiveStepChangingArgsEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.b = function (a) {
        if (WebActiveStepChangingArgsEventArgsDescriptionMetadata.a == null) {
            WebActiveStepChangingArgsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActiveStepChangingArgsEventArgsDescriptionMetadata.c(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
        WebActiveStepChangingArgsDetailDescriptionMetadata.d(a);
    };
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActiveStepChangingArgsEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Detail", "ExportedType:WebActiveStepChangingArgsDetail");
    };
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.d = function (a) {
        WebActiveStepChangingArgsEventArgsDescriptionMetadata.b(a);
        a.ad("WebActiveStepChangingArgsEventArgs", function () { return new WebActiveStepChangingArgsEventArgsDescription(); });
        a.ac("WebActiveStepChangingArgsEventArgs", WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
    };
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.$t = markType(WebActiveStepChangingArgsEventArgsDescriptionMetadata, 'WebActiveStepChangingArgsEventArgsDescriptionMetadata');
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.a = null;
    return WebActiveStepChangingArgsEventArgsDescriptionMetadata;
}(Base));
export { WebActiveStepChangingArgsEventArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebActiveStepChangingArgsEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebActiveStepChangingArgsDetailDescriptionMetadata } from "./WebActiveStepChangingArgsDetailDescriptionMetadata";
import { WebActiveStepChangingArgsEventArgsDescription } from "./WebActiveStepChangingArgsEventArgsDescription";
/**
 * @hidden
 */
var WebActiveStepChangingArgsEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActiveStepChangingArgsEventArgsDescriptionMetadata, _super);
    function WebActiveStepChangingArgsEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.b = function (a) {
        if (WebActiveStepChangingArgsEventArgsDescriptionMetadata.a == null) {
            WebActiveStepChangingArgsEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActiveStepChangingArgsEventArgsDescriptionMetadata.c(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
        WebActiveStepChangingArgsDetailDescriptionMetadata.d(a);
    };
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActiveStepChangingArgsEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("Detail", "ExportedType:WebActiveStepChangingArgsDetail");
    };
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.d = function (a) {
        WebActiveStepChangingArgsEventArgsDescriptionMetadata.b(a);
        a.ae("WebActiveStepChangingArgsEventArgs", function () { return new WebActiveStepChangingArgsEventArgsDescription(); });
        a.ad("WebActiveStepChangingArgsEventArgs", WebActiveStepChangingArgsEventArgsDescriptionMetadata.a);
    };
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.$t = markType(WebActiveStepChangingArgsEventArgsDescriptionMetadata, 'WebActiveStepChangingArgsEventArgsDescriptionMetadata');
    WebActiveStepChangingArgsEventArgsDescriptionMetadata.a = null;
    return WebActiveStepChangingArgsEventArgsDescriptionMetadata;
}(Base));
export { WebActiveStepChangingArgsEventArgsDescriptionMetadata };
